"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing
import yandex.cloud.ai.assistants.v1.searchindex.search_index_pb2
import yandex.cloud.ai.files.v1.file_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Message(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _MessageStatus:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _MessageStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Message._MessageStatus.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        MESSAGE_STATUS_UNSPECIFIED: Message._MessageStatus.ValueType  # 0
        """Unspecified message status."""
        COMPLETED: Message._MessageStatus.ValueType  # 1
        """Message was successfully created by a user or generated by an assistant."""
        TRUNCATED: Message._MessageStatus.ValueType  # 2
        """Message generation was truncated due to reaching the maximum allowed number of tokens."""
        FILTERED_CONTENT: Message._MessageStatus.ValueType  # 3
        """Message generation was stopped because potentially sensitive content was detected either in the prompt or in the generated response."""

    class MessageStatus(_MessageStatus, metaclass=_MessageStatusEnumTypeWrapper):
        """Enum representing the status of a message."""

    MESSAGE_STATUS_UNSPECIFIED: Message.MessageStatus.ValueType  # 0
    """Unspecified message status."""
    COMPLETED: Message.MessageStatus.ValueType  # 1
    """Message was successfully created by a user or generated by an assistant."""
    TRUNCATED: Message.MessageStatus.ValueType  # 2
    """Message generation was truncated due to reaching the maximum allowed number of tokens."""
    FILTERED_CONTENT: Message.MessageStatus.ValueType  # 3
    """Message generation was stopped because potentially sensitive content was detected either in the prompt or in the generated response."""

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    THREAD_ID_FIELD_NUMBER: builtins.int
    CREATED_BY_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    AUTHOR_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    CITATIONS_FIELD_NUMBER: builtins.int
    id: builtins.str
    """Unique identifier of the message."""
    thread_id: builtins.str
    """ID of the thread that this message belongs to."""
    created_by: builtins.str
    """Identifier of the subject who created this message."""
    status: global___Message.MessageStatus.ValueType
    """Status of the message."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Timestamp representing when the message was created."""

    @property
    def author(self) -> global___Author:
        """Author of the message, containing details about the message's creator."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Set of key-value pairs that can be used to organize and categorize the message."""

    @property
    def content(self) -> global___MessageContent:
        """Content of the message."""

    @property
    def citations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Citation]:
        """List of citations used to generate the message."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        thread_id: builtins.str = ...,
        created_by: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        author: global___Author | None = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        content: global___MessageContent | None = ...,
        status: global___Message.MessageStatus.ValueType = ...,
        citations: collections.abc.Iterable[global___Citation] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["author", b"author", "content", b"content", "created_at", b"created_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["author", b"author", "citations", b"citations", "content", b"content", "created_at", b"created_at", "created_by", b"created_by", "id", b"id", "labels", b"labels", "status", b"status", "thread_id", b"thread_id"]) -> None: ...

global___Message = Message

@typing.final
class MessageContent(google.protobuf.message.Message):
    """Represents the content of a message, which can consist of multiple parts."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTENT_FIELD_NUMBER: builtins.int
    @property
    def content(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ContentPart]:
        """A list of content parts that make up the message."""

    def __init__(
        self,
        *,
        content: collections.abc.Iterable[global___ContentPart] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["content", b"content"]) -> None: ...

global___MessageContent = MessageContent

@typing.final
class MessageData(google.protobuf.message.Message):
    """Represents the data required to create or initialize a message in a thread.
    This message is used, for example, to initialize a thread with some messages upon its creation.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    AUTHOR_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    @property
    def author(self) -> global___Author:
        """Author of the message, containing details about the message's creator."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Set of key-value pairs that can be used to organize and categorize the message."""

    @property
    def content(self) -> global___MessageContent:
        """Content of the message."""

    def __init__(
        self,
        *,
        author: global___Author | None = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        content: global___MessageContent | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["author", b"author", "content", b"content"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["author", b"author", "content", b"content", "labels", b"labels"]) -> None: ...

global___MessageData = MessageData

@typing.final
class Text(google.protobuf.message.Message):
    """Text represents a textual content part of a message."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTENT_FIELD_NUMBER: builtins.int
    content: builtins.str
    """Text content of the message."""
    def __init__(
        self,
        *,
        content: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["content", b"content"]) -> None: ...

global___Text = Text

@typing.final
class ContentPart(google.protobuf.message.Message):
    """ContentPart represents an individual part of the message content, which can be of various types."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    @property
    def text(self) -> global___Text:
        """Text content of the message part."""

    def __init__(
        self,
        *,
        text: global___Text | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["PartType", b"PartType", "text", b"text"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["PartType", b"PartType", "text", b"text"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["PartType", b"PartType"]) -> typing.Literal["text"] | None: ...

global___ContentPart = ContentPart

@typing.final
class Author(google.protobuf.message.Message):
    """Author of the message, containing details about the message's creator."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    id: builtins.str
    """Unique identifier of the author. This could be either the user's ID or the assistant's ID, depending on the role."""
    role: builtins.str
    """Role of the author, indicating whether the message was created by a "user" or an "assistant"."""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        role: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["id", b"id", "role", b"role"]) -> None: ...

global___Author = Author

@typing.final
class Citation(google.protobuf.message.Message):
    """Represents a citation used for generating a message."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SOURCES_FIELD_NUMBER: builtins.int
    @property
    def sources(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Source]:
        """List of sources for citation."""

    def __init__(
        self,
        *,
        sources: collections.abc.Iterable[global___Source] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["sources", b"sources"]) -> None: ...

global___Citation = Citation

@typing.final
class Source(google.protobuf.message.Message):
    """Represents a source used for generating a message citation."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHUNK_FIELD_NUMBER: builtins.int
    @property
    def chunk(self) -> global___FileChunk:
        """File chunk source."""

    def __init__(
        self,
        *,
        chunk: global___FileChunk | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["SourceType", b"SourceType", "chunk", b"chunk"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["SourceType", b"SourceType", "chunk", b"chunk"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["SourceType", b"SourceType"]) -> typing.Literal["chunk"] | None: ...

global___Source = Source

@typing.final
class FileChunk(google.protobuf.message.Message):
    """FileChunk represents a chunk of a file used as a source."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SEARCH_INDEX_FIELD_NUMBER: builtins.int
    SOURCE_FILE_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    @property
    def search_index(self) -> yandex.cloud.ai.assistants.v1.searchindex.search_index_pb2.SearchIndex:
        """Search index associated with the file chunk."""

    @property
    def source_file(self) -> yandex.cloud.ai.files.v1.file_pb2.File:
        """The original file from which the chunk is derived."""

    @property
    def content(self) -> global___ChunkContent:
        """Content of the file chunk."""

    def __init__(
        self,
        *,
        search_index: yandex.cloud.ai.assistants.v1.searchindex.search_index_pb2.SearchIndex | None = ...,
        source_file: yandex.cloud.ai.files.v1.file_pb2.File | None = ...,
        content: global___ChunkContent | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["content", b"content", "search_index", b"search_index", "source_file", b"source_file"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["content", b"content", "search_index", b"search_index", "source_file", b"source_file"]) -> None: ...

global___FileChunk = FileChunk

@typing.final
class ChunkContent(google.protobuf.message.Message):
    """Represents the content of a file chunk."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTENT_FIELD_NUMBER: builtins.int
    @property
    def content(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ContentPart]:
        """A list of content parts that make up the chunk."""

    def __init__(
        self,
        *,
        content: collections.abc.Iterable[global___ContentPart] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["content", b"content"]) -> None: ...

global___ChunkContent = ChunkContent



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/mdb/greenplum/v1/pxf_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/mdb/greenplum/v1/pxf_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.mdb.greenplum.v1 import pxf_pb2 as yandex_dot_cloud_dot_mdb_dot_greenplum_dot_v1_dot_pxf__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/yandex/cloud/mdb/greenplum/v1/pxf_service.proto\x12\x1dyandex.cloud.mdb.greenplum.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\'yandex/cloud/mdb/greenplum/v1/pxf.proto\"}\n\x1b\x43reatePXFDatasourceMetadata\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12<\n\x0f\x64\x61tasource_name\x18\x02 \x01(\tB#\xe8\xc7\x31\x01\xf2\xc7\x31\x12^[^\\|/*?.,;\"\'<>]+$\x8a\xc8\x31\x05\x33-200\"}\n\x1bUpdatePXFDatasourceMetadata\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12<\n\x0f\x64\x61tasource_name\x18\x02 \x01(\tB#\xe8\xc7\x31\x01\xf2\xc7\x31\x12^[^\\|/*?.,;\"\'<>]+$\x8a\xc8\x31\x05\x33-200\"}\n\x1b\x44\x65letePXFDatasourceMetadata\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12<\n\x0f\x64\x61tasource_name\x18\x02 \x01(\tB#\xe8\xc7\x31\x01\xf2\xc7\x31\x12^[^\\|/*?.,;\"\'<>]+$\x8a\xc8\x31\x05\x33-200\"=\n\x19ListPXFDatasourcesRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"_\n\x1aListPXFDatasourcesResponse\x12\x41\n\x0b\x64\x61tasources\x18\x01 \x03(\x0b\x32,.yandex.cloud.mdb.greenplum.v1.PXFDatasource\"\x80\x01\n\x1a\x43reatePXFDatasourceRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12@\n\ndatasource\x18\x02 \x01(\x0b\x32,.yandex.cloud.mdb.greenplum.v1.PXFDatasource\"\xb1\x01\n\x1aUpdatePXFDatasourceRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12@\n\ndatasource\x18\x03 \x01(\x0b\x32,.yandex.cloud.mdb.greenplum.v1.PXFDatasource\"|\n\x1a\x44\x65letePXFDatasourceRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12<\n\x0f\x64\x61tasource_name\x18\x02 \x01(\tB#\xe8\xc7\x31\x01\xf2\xc7\x31\x12^[^\\|/*?.,;\"\'<>]+$\x8a\xc8\x31\x05\x33-2002\x93\x07\n\x14PXFDatasourceService\x12\xc0\x01\n\x04List\x12\x38.yandex.cloud.mdb.greenplum.v1.ListPXFDatasourcesRequest\x1a\x39.yandex.cloud.mdb.greenplum.v1.ListPXFDatasourcesResponse\"C\x82\xd3\xe4\x93\x02=\x12;/managed-greenplum/v1/clusters/{cluster_id}/pxf_datasources\x12\xde\x01\n\x06\x43reate\x12\x39.yandex.cloud.mdb.greenplum.v1.CreatePXFDatasourceRequest\x1a!.yandex.cloud.operation.Operation\"v\xb2\xd2*,\n\x1b\x43reatePXFDatasourceMetadata\x12\rPXFDatasource\x82\xd3\xe4\x93\x02@\";/managed-greenplum/v1/clusters/{cluster_id}/pxf_datasources:\x01*\x12\xde\x01\n\x06Update\x12\x39.yandex.cloud.mdb.greenplum.v1.UpdatePXFDatasourceRequest\x1a!.yandex.cloud.operation.Operation\"v\xb2\xd2*,\n\x1bUpdatePXFDatasourceMetadata\x12\rPXFDatasource\x82\xd3\xe4\x93\x02@2;/managed-greenplum/v1/clusters/{cluster_id}/pxf_datasources:\x01*\x12\xf5\x01\n\x06\x44\x65lete\x12\x39.yandex.cloud.mdb.greenplum.v1.DeletePXFDatasourceRequest\x1a!.yandex.cloud.operation.Operation\"\x8c\x01\xb2\xd2*4\n\x1b\x44\x65letePXFDatasourceMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02N*L/managed-greenplum/v1/clusters/{cluster_id}/pxf_datasource/{datasource_name}Bp\n!yandex.cloud.api.mdb.greenplum.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/greenplum/v1;greenplumb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.greenplum.v1.pxf_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n!yandex.cloud.api.mdb.greenplum.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/greenplum/v1;greenplum'
  _globals['_CREATEPXFDATASOURCEMETADATA'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_CREATEPXFDATASOURCEMETADATA'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATEPXFDATASOURCEMETADATA'].fields_by_name['datasource_name']._loaded_options = None
  _globals['_CREATEPXFDATASOURCEMETADATA'].fields_by_name['datasource_name']._serialized_options = b'\350\3071\001\362\3071\022^[^\\|/*?.,;\"\'<>]+$\212\3101\0053-200'
  _globals['_UPDATEPXFDATASOURCEMETADATA'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_UPDATEPXFDATASOURCEMETADATA'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATEPXFDATASOURCEMETADATA'].fields_by_name['datasource_name']._loaded_options = None
  _globals['_UPDATEPXFDATASOURCEMETADATA'].fields_by_name['datasource_name']._serialized_options = b'\350\3071\001\362\3071\022^[^\\|/*?.,;\"\'<>]+$\212\3101\0053-200'
  _globals['_DELETEPXFDATASOURCEMETADATA'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_DELETEPXFDATASOURCEMETADATA'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DELETEPXFDATASOURCEMETADATA'].fields_by_name['datasource_name']._loaded_options = None
  _globals['_DELETEPXFDATASOURCEMETADATA'].fields_by_name['datasource_name']._serialized_options = b'\350\3071\001\362\3071\022^[^\\|/*?.,;\"\'<>]+$\212\3101\0053-200'
  _globals['_LISTPXFDATASOURCESREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_LISTPXFDATASOURCESREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATEPXFDATASOURCEREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_CREATEPXFDATASOURCEREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATEPXFDATASOURCEREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_UPDATEPXFDATASOURCEREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DELETEPXFDATASOURCEREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_DELETEPXFDATASOURCEREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DELETEPXFDATASOURCEREQUEST'].fields_by_name['datasource_name']._loaded_options = None
  _globals['_DELETEPXFDATASOURCEREQUEST'].fields_by_name['datasource_name']._serialized_options = b'\350\3071\001\362\3071\022^[^\\|/*?.,;\"\'<>]+$\212\3101\0053-200'
  _globals['_PXFDATASOURCESERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_PXFDATASOURCESERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002=\022;/managed-greenplum/v1/clusters/{cluster_id}/pxf_datasources'
  _globals['_PXFDATASOURCESERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_PXFDATASOURCESERVICE'].methods_by_name['Create']._serialized_options = b'\262\322*,\n\033CreatePXFDatasourceMetadata\022\rPXFDatasource\202\323\344\223\002@\";/managed-greenplum/v1/clusters/{cluster_id}/pxf_datasources:\001*'
  _globals['_PXFDATASOURCESERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_PXFDATASOURCESERVICE'].methods_by_name['Update']._serialized_options = b'\262\322*,\n\033UpdatePXFDatasourceMetadata\022\rPXFDatasource\202\323\344\223\002@2;/managed-greenplum/v1/clusters/{cluster_id}/pxf_datasources:\001*'
  _globals['_PXFDATASOURCESERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_PXFDATASOURCESERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*4\n\033DeletePXFDatasourceMetadata\022\025google.protobuf.Empty\202\323\344\223\002N*L/managed-greenplum/v1/clusters/{cluster_id}/pxf_datasource/{datasource_name}'
  _globals['_CREATEPXFDATASOURCEMETADATA']._serialized_start=292
  _globals['_CREATEPXFDATASOURCEMETADATA']._serialized_end=417
  _globals['_UPDATEPXFDATASOURCEMETADATA']._serialized_start=419
  _globals['_UPDATEPXFDATASOURCEMETADATA']._serialized_end=544
  _globals['_DELETEPXFDATASOURCEMETADATA']._serialized_start=546
  _globals['_DELETEPXFDATASOURCEMETADATA']._serialized_end=671
  _globals['_LISTPXFDATASOURCESREQUEST']._serialized_start=673
  _globals['_LISTPXFDATASOURCESREQUEST']._serialized_end=734
  _globals['_LISTPXFDATASOURCESRESPONSE']._serialized_start=736
  _globals['_LISTPXFDATASOURCESRESPONSE']._serialized_end=831
  _globals['_CREATEPXFDATASOURCEREQUEST']._serialized_start=834
  _globals['_CREATEPXFDATASOURCEREQUEST']._serialized_end=962
  _globals['_UPDATEPXFDATASOURCEREQUEST']._serialized_start=965
  _globals['_UPDATEPXFDATASOURCEREQUEST']._serialized_end=1142
  _globals['_DELETEPXFDATASOURCEREQUEST']._serialized_start=1144
  _globals['_DELETEPXFDATASOURCEREQUEST']._serialized_end=1268
  _globals['_PXFDATASOURCESERVICE']._serialized_start=1271
  _globals['_PXFDATASOURCESERVICE']._serialized_end=2186
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/compute/v1/hardware_generation.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/compute/v1/hardware_generation.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1yandex/cloud/compute/v1/hardware_generation.proto\x12\x17yandex.cloud.compute.v1\"\xc2\x01\n\x12HardwareGeneration\x12J\n\x0flegacy_features\x18\x01 \x01(\x0b\x32/.yandex.cloud.compute.v1.LegacyHardwareFeaturesH\x00\x12T\n\x14generation2_features\x18\x02 \x01(\x0b\x32\x34.yandex.cloud.compute.v1.Generation2HardwareFeaturesH\x00\x42\n\n\x08\x66\x65\x61tures\"T\n\x16LegacyHardwareFeatures\x12:\n\x0cpci_topology\x18\x01 \x01(\x0e\x32$.yandex.cloud.compute.v1.PCITopology\"\x1d\n\x1bGeneration2HardwareFeatures*U\n\x0bPCITopology\x12\x1c\n\x18PCI_TOPOLOGY_UNSPECIFIED\x10\x00\x12\x13\n\x0fPCI_TOPOLOGY_V1\x10\x01\x12\x13\n\x0fPCI_TOPOLOGY_V2\x10\x02\x42\x62\n\x1byandex.cloud.api.compute.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/compute/v1;computeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.compute.v1.hardware_generation_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033yandex.cloud.api.compute.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/compute/v1;compute'
  _globals['_PCITOPOLOGY']._serialized_start=392
  _globals['_PCITOPOLOGY']._serialized_end=477
  _globals['_HARDWAREGENERATION']._serialized_start=79
  _globals['_HARDWAREGENERATION']._serialized_end=273
  _globals['_LEGACYHARDWAREFEATURES']._serialized_start=275
  _globals['_LEGACYHARDWAREFEATURES']._serialized_end=359
  _globals['_GENERATION2HARDWAREFEATURES']._serialized_start=361
  _globals['_GENERATION2HARDWAREFEATURES']._serialized_end=390
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/ai/assistants/v1/users/user_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/ai/assistants/v1/users/user_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.ai.common import common_pb2 as yandex_dot_cloud_dot_ai_dot_common_dot_common__pb2
from yandex.cloud.ai.assistants.v1.users import user_pb2 as yandex_dot_cloud_dot_ai_dot_assistants_dot_v1_dot_users_dot_user__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6yandex/cloud/ai/assistants/v1/users/user_service.proto\x12#yandex.cloud.ai.assistants.v1.users\x1a#yandex/cloud/ai/common/common.proto\x1a.yandex/cloud/ai/assistants/v1/users/user.proto\x1a\x1dyandex/cloud/validation.proto\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\"\xa7\x02\n\x11\x43reateUserRequest\x12\x17\n\tfolder_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x0e\n\x06source\x18\x04 \x01(\t\x12\x43\n\x11\x65xpiration_config\x18\x05 \x01(\x0b\x32(.yandex.cloud.ai.common.ExpirationConfig\x12R\n\x06labels\x18\x06 \x03(\x0b\x32\x42.yandex.cloud.ai.assistants.v1.users.CreateUserRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\'\n\x0eGetUserRequest\x12\x15\n\x07user_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"\xcc\x02\n\x11UpdateUserRequest\x12\x15\n\x07user_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x35\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe8\xc7\x31\x01\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x43\n\x11\x65xpiration_config\x18\x05 \x01(\x0b\x32(.yandex.cloud.ai.common.ExpirationConfig\x12R\n\x06labels\x18\x06 \x03(\x0b\x32\x42.yandex.cloud.ai.assistants.v1.users.UpdateUserRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"*\n\x11\x44\x65leteUserRequest\x12\x15\n\x07user_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"\x14\n\x12\x44\x65leteUserResponse\"R\n\x10ListUsersRequest\x12\x17\n\tfolder_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x11\n\tpage_size\x18\x02 \x01(\x03\x12\x12\n\npage_token\x18\x03 \x01(\t\"f\n\x11ListUsersResponse\x12\x38\n\x05users\x18\x01 \x03(\x0b\x32).yandex.cloud.ai.assistants.v1.users.User\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xe6\x05\n\x0bUserService\x12\x87\x01\n\x06\x43reate\x12\x36.yandex.cloud.ai.assistants.v1.users.CreateUserRequest\x1a).yandex.cloud.ai.assistants.v1.users.User\"\x1a\x82\xd3\xe4\x93\x02\x14\"\x0f/users/v1/users:\x01*\x12\x88\x01\n\x03Get\x12\x33.yandex.cloud.ai.assistants.v1.users.GetUserRequest\x1a).yandex.cloud.ai.assistants.v1.users.User\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/users/v1/users/{user_id}\x12\x91\x01\n\x06Update\x12\x36.yandex.cloud.ai.assistants.v1.users.UpdateUserRequest\x1a).yandex.cloud.ai.assistants.v1.users.User\"$\x82\xd3\xe4\x93\x02\x1e\x32\x19/users/v1/users/{user_id}:\x01*\x12\x9c\x01\n\x06\x44\x65lete\x12\x36.yandex.cloud.ai.assistants.v1.users.DeleteUserRequest\x1a\x37.yandex.cloud.ai.assistants.v1.users.DeleteUserResponse\"!\x82\xd3\xe4\x93\x02\x1b*\x19/users/v1/users/{user_id}\x12\x8e\x01\n\x04List\x12\x35.yandex.cloud.ai.assistants.v1.users.ListUsersRequest\x1a\x36.yandex.cloud.ai.assistants.v1.users.ListUsersResponse\"\x17\x82\xd3\xe4\x93\x02\x11\x12\x0f/users/v1/usersBx\n\'yandex.cloud.api.ai.assistants.v1.usersZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/assistants/v1/users;usersb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.ai.assistants.v1.users.user_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\'yandex.cloud.api.ai.assistants.v1.usersZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/assistants/v1/users;users'
  _globals['_CREATEUSERREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_CREATEUSERREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CREATEUSERREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_CREATEUSERREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001'
  _globals['_GETUSERREQUEST'].fields_by_name['user_id']._loaded_options = None
  _globals['_GETUSERREQUEST'].fields_by_name['user_id']._serialized_options = b'\350\3071\001'
  _globals['_UPDATEUSERREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_UPDATEUSERREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_UPDATEUSERREQUEST'].fields_by_name['user_id']._loaded_options = None
  _globals['_UPDATEUSERREQUEST'].fields_by_name['user_id']._serialized_options = b'\350\3071\001'
  _globals['_UPDATEUSERREQUEST'].fields_by_name['update_mask']._loaded_options = None
  _globals['_UPDATEUSERREQUEST'].fields_by_name['update_mask']._serialized_options = b'\350\3071\001'
  _globals['_DELETEUSERREQUEST'].fields_by_name['user_id']._loaded_options = None
  _globals['_DELETEUSERREQUEST'].fields_by_name['user_id']._serialized_options = b'\350\3071\001'
  _globals['_LISTUSERSREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_LISTUSERSREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001'
  _globals['_USERSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_USERSERVICE'].methods_by_name['Create']._serialized_options = b'\202\323\344\223\002\024\"\017/users/v1/users:\001*'
  _globals['_USERSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_USERSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002\033\022\031/users/v1/users/{user_id}'
  _globals['_USERSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_USERSERVICE'].methods_by_name['Update']._serialized_options = b'\202\323\344\223\002\0362\031/users/v1/users/{user_id}:\001*'
  _globals['_USERSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_USERSERVICE'].methods_by_name['Delete']._serialized_options = b'\202\323\344\223\002\033*\031/users/v1/users/{user_id}'
  _globals['_USERSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_USERSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\021\022\017/users/v1/users'
  _globals['_CREATEUSERREQUEST']._serialized_start=276
  _globals['_CREATEUSERREQUEST']._serialized_end=571
  _globals['_CREATEUSERREQUEST_LABELSENTRY']._serialized_start=526
  _globals['_CREATEUSERREQUEST_LABELSENTRY']._serialized_end=571
  _globals['_GETUSERREQUEST']._serialized_start=573
  _globals['_GETUSERREQUEST']._serialized_end=612
  _globals['_UPDATEUSERREQUEST']._serialized_start=615
  _globals['_UPDATEUSERREQUEST']._serialized_end=947
  _globals['_UPDATEUSERREQUEST_LABELSENTRY']._serialized_start=526
  _globals['_UPDATEUSERREQUEST_LABELSENTRY']._serialized_end=571
  _globals['_DELETEUSERREQUEST']._serialized_start=949
  _globals['_DELETEUSERREQUEST']._serialized_end=991
  _globals['_DELETEUSERRESPONSE']._serialized_start=993
  _globals['_DELETEUSERRESPONSE']._serialized_end=1013
  _globals['_LISTUSERSREQUEST']._serialized_start=1015
  _globals['_LISTUSERSREQUEST']._serialized_end=1097
  _globals['_LISTUSERSRESPONSE']._serialized_start=1099
  _globals['_LISTUSERSRESPONSE']._serialized_end=1201
  _globals['_USERSERVICE']._serialized_start=1204
  _globals['_USERSERVICE']._serialized_end=1946
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class User(google.protobuf.message.Message):
    """A SPQR User resource. For more information, see the 
    [Developer's Guide](/docs/managed-spqr/concepts).
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    CLUSTER_ID_FIELD_NUMBER: builtins.int
    PERMISSIONS_FIELD_NUMBER: builtins.int
    SETTINGS_FIELD_NUMBER: builtins.int
    GRANTS_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the SPQR user."""
    cluster_id: builtins.str
    """ID of the SPQR cluster the user belongs to."""
    @property
    def permissions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Permission]:
        """Set of permissions granted to the user."""

    @property
    def settings(self) -> global___UserSettings:
        """SPQR Settings for this user"""

    @property
    def grants(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """User grants"""

    def __init__(
        self,
        *,
        name: builtins.str = ...,
        cluster_id: builtins.str = ...,
        permissions: collections.abc.Iterable[global___Permission] | None = ...,
        settings: global___UserSettings | None = ...,
        grants: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["settings", b"settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "grants", b"grants", "name", b"name", "permissions", b"permissions", "settings", b"settings"]) -> None: ...

global___User = User

@typing.final
class Permission(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATABASE_NAME_FIELD_NUMBER: builtins.int
    database_name: builtins.str
    """Name of the database that the permission grants access to."""
    def __init__(
        self,
        *,
        database_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["database_name", b"database_name"]) -> None: ...

global___Permission = Permission

@typing.final
class UserSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    PASSWORD_FIELD_NUMBER: builtins.int
    PERMISSIONS_FIELD_NUMBER: builtins.int
    SETTINGS_FIELD_NUMBER: builtins.int
    GRANTS_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the SPQR user."""
    password: builtins.str
    """Password of the SPQR user."""
    @property
    def permissions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Permission]:
        """Set of permissions to grant to the user."""

    @property
    def settings(self) -> global___UserSettings:
        """SPQR Settings for this user"""

    @property
    def grants(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """User grants"""

    def __init__(
        self,
        *,
        name: builtins.str = ...,
        password: builtins.str = ...,
        permissions: collections.abc.Iterable[global___Permission] | None = ...,
        settings: global___UserSettings | None = ...,
        grants: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["settings", b"settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["grants", b"grants", "name", b"name", "password", b"password", "permissions", b"permissions", "settings", b"settings"]) -> None: ...

global___UserSpec = UserSpec

@typing.final
class UserSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONNECTION_LIMIT_FIELD_NUMBER: builtins.int
    CONNECTION_RETRIES_FIELD_NUMBER: builtins.int
    @property
    def connection_limit(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def connection_retries(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    def __init__(
        self,
        *,
        connection_limit: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        connection_retries: google.protobuf.wrappers_pb2.Int64Value | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["connection_limit", b"connection_limit", "connection_retries", b"connection_retries"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["connection_limit", b"connection_limit", "connection_retries", b"connection_retries"]) -> None: ...

global___UserSettings = UserSettings



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/organizationmanager/v1/ssh_certificate_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/organizationmanager/v1/ssh_certificate_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAyandex/cloud/organizationmanager/v1/ssh_certificate_service.proto\x12#yandex.cloud.organizationmanager.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1dyandex/cloud/validation.proto\"\xdf\x01\n\x1dGenerateSshCertificateRequest\x12\x1c\n\x08\x63loud_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50H\x00\x12#\n\x0forganization_id\x18\x02 \x01(\tB\x08\x8a\xc8\x31\x04<=50H\x00\x12\x1e\n\nsubject_id\x18\x03 \x01(\tB\x08\x8a\xc8\x31\x04<=50H\x01\x12\x1c\n\x08os_login\x18\x04 \x01(\tB\x08\x8a\xc8\x31\x04<=32H\x01\x12#\n\npublic_key\x18\x05 \x01(\tB\x0f\xe8\xc7\x31\x01\x8a\xc8\x31\x07<=15000B\r\n\x05scope\x12\x04\xc0\xc1\x31\x01\x42\t\n\x07subject\"<\n\x1eGenerateSshCertificateResponse\x12\x1a\n\x12signed_certificate\x18\x01 \x01(\t2\xeb\x01\n\x15SshCertificateService\x12\xd1\x01\n\x08Generate\x12\x42.yandex.cloud.organizationmanager.v1.GenerateSshCertificateRequest\x1a\x43.yandex.cloud.organizationmanager.v1.GenerateSshCertificateResponse\"<\x82\xd3\xe4\x93\x02\x36\"1/organization-manager/v1/sshCertificates:generate:\x01*B\x86\x01\n\'yandex.cloud.api.organizationmanager.v1Z[github.com/yandex-cloud/go-genproto/yandex/cloud/organizationmanager/v1;organizationmanagerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.organizationmanager.v1.ssh_certificate_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\'yandex.cloud.api.organizationmanager.v1Z[github.com/yandex-cloud/go-genproto/yandex/cloud/organizationmanager/v1;organizationmanager'
  _globals['_GENERATESSHCERTIFICATEREQUEST'].oneofs_by_name['scope']._loaded_options = None
  _globals['_GENERATESSHCERTIFICATEREQUEST'].oneofs_by_name['scope']._serialized_options = b'\300\3011\001'
  _globals['_GENERATESSHCERTIFICATEREQUEST'].fields_by_name['cloud_id']._loaded_options = None
  _globals['_GENERATESSHCERTIFICATEREQUEST'].fields_by_name['cloud_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_GENERATESSHCERTIFICATEREQUEST'].fields_by_name['organization_id']._loaded_options = None
  _globals['_GENERATESSHCERTIFICATEREQUEST'].fields_by_name['organization_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_GENERATESSHCERTIFICATEREQUEST'].fields_by_name['subject_id']._loaded_options = None
  _globals['_GENERATESSHCERTIFICATEREQUEST'].fields_by_name['subject_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_GENERATESSHCERTIFICATEREQUEST'].fields_by_name['os_login']._loaded_options = None
  _globals['_GENERATESSHCERTIFICATEREQUEST'].fields_by_name['os_login']._serialized_options = b'\212\3101\004<=32'
  _globals['_GENERATESSHCERTIFICATEREQUEST'].fields_by_name['public_key']._loaded_options = None
  _globals['_GENERATESSHCERTIFICATEREQUEST'].fields_by_name['public_key']._serialized_options = b'\350\3071\001\212\3101\007<=15000'
  _globals['_SSHCERTIFICATESERVICE'].methods_by_name['Generate']._loaded_options = None
  _globals['_SSHCERTIFICATESERVICE'].methods_by_name['Generate']._serialized_options = b'\202\323\344\223\0026\"1/organization-manager/v1/sshCertificates:generate:\001*'
  _globals['_GENERATESSHCERTIFICATEREQUEST']._serialized_start=168
  _globals['_GENERATESSHCERTIFICATEREQUEST']._serialized_end=391
  _globals['_GENERATESSHCERTIFICATERESPONSE']._serialized_start=393
  _globals['_GENERATESSHCERTIFICATERESPONSE']._serialized_end=453
  _globals['_SSHCERTIFICATESERVICE']._serialized_start=456
  _globals['_SSHCERTIFICATESERVICE']._serialized_end=691
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class DiskPlacementGroup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[DiskPlacementGroup._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNSPECIFIED: DiskPlacementGroup._Status.ValueType  # 0
        CREATING: DiskPlacementGroup._Status.ValueType  # 1
        READY: DiskPlacementGroup._Status.ValueType  # 2
        DELETING: DiskPlacementGroup._Status.ValueType  # 4

    class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...
    STATUS_UNSPECIFIED: DiskPlacementGroup.Status.ValueType  # 0
    CREATING: DiskPlacementGroup.Status.ValueType  # 1
    READY: DiskPlacementGroup.Status.ValueType  # 2
    DELETING: DiskPlacementGroup.Status.ValueType  # 4

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    ZONE_ID_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    SPREAD_PLACEMENT_STRATEGY_FIELD_NUMBER: builtins.int
    PARTITION_PLACEMENT_STRATEGY_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the placement group."""
    folder_id: builtins.str
    """ID of the folder that the placement group belongs to."""
    name: builtins.str
    """Name of the placement group.
    The name is unique within the folder.
    """
    description: builtins.str
    """Description of the placement group."""
    zone_id: builtins.str
    """ID of the availability zone where the placement group resides."""
    status: global___DiskPlacementGroup.Status.ValueType
    """Current status of the placement group"""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp in [RFC3339](https://www.ietf.org/rfc/rfc3339.txt) text format."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `key:value` pairs."""

    @property
    def spread_placement_strategy(self) -> global___DiskSpreadPlacementStrategy:
        """Distribute disks over distinct failure domains."""

    @property
    def partition_placement_strategy(self) -> global___DiskPartitionPlacementStrategy:
        """Distribute disks over partitions."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        folder_id: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        zone_id: builtins.str = ...,
        status: global___DiskPlacementGroup.Status.ValueType = ...,
        spread_placement_strategy: global___DiskSpreadPlacementStrategy | None = ...,
        partition_placement_strategy: global___DiskPartitionPlacementStrategy | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at", "partition_placement_strategy", b"partition_placement_strategy", "placement_strategy", b"placement_strategy", "spread_placement_strategy", b"spread_placement_strategy"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["created_at", b"created_at", "description", b"description", "folder_id", b"folder_id", "id", b"id", "labels", b"labels", "name", b"name", "partition_placement_strategy", b"partition_placement_strategy", "placement_strategy", b"placement_strategy", "spread_placement_strategy", b"spread_placement_strategy", "status", b"status", "zone_id", b"zone_id"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["placement_strategy", b"placement_strategy"]) -> typing.Literal["spread_placement_strategy", "partition_placement_strategy"] | None: ...

global___DiskPlacementGroup = DiskPlacementGroup

@typing.final
class DiskSpreadPlacementStrategy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DiskSpreadPlacementStrategy = DiskSpreadPlacementStrategy

@typing.final
class DiskPartitionPlacementStrategy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PARTITIONS_FIELD_NUMBER: builtins.int
    partitions: builtins.int
    def __init__(
        self,
        *,
        partitions: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["partitions", b"partitions"]) -> None: ...

global___DiskPartitionPlacementStrategy = DiskPartitionPlacementStrategy



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/billing/v1/sku.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/billing/v1/sku.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!yandex/cloud/billing/v1/sku.proto\x12\x17yandex.cloud.billing.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\xa1\x01\n\x03Sku\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x12\n\nservice_id\x18\x04 \x01(\t\x12\x14\n\x0cpricing_unit\x18\x05 \x01(\t\x12\x41\n\x10pricing_versions\x18\x06 \x03(\x0b\x32\'.yandex.cloud.billing.v1.PricingVersion\"\xc8\x01\n\x0ePricingVersion\x12\x39\n\x04type\x18\x01 \x01(\x0e\x32+.yandex.cloud.billing.v1.PricingVersionType\x12\x32\n\x0e\x65\x66\x66\x65\x63tive_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12G\n\x13pricing_expressions\x18\x03 \x03(\x0b\x32*.yandex.cloud.billing.v1.PricingExpression\"A\n\x11PricingExpression\x12,\n\x05rates\x18\x02 \x03(\x0b\x32\x1d.yandex.cloud.billing.v1.Rate\"L\n\x04Rate\x12\x1e\n\x16start_pricing_quantity\x18\x01 \x01(\t\x12\x12\n\nunit_price\x18\x02 \x01(\t\x12\x10\n\x08\x63urrency\x18\x03 \x01(\t*`\n\x12PricingVersionType\x12$\n PRICING_VERSION_TYPE_UNSPECIFIED\x10\x00\x12\x10\n\x0cSTREET_PRICE\x10\x01\x12\x12\n\x0e\x43ONTRACT_PRICE\x10\x02\x42\x62\n\x1byandex.cloud.api.billing.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/billing/v1;billingb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.billing.v1.sku_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033yandex.cloud.api.billing.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/billing/v1;billing'
  _globals['_PRICINGVERSIONTYPE']._serialized_start=607
  _globals['_PRICINGVERSIONTYPE']._serialized_end=703
  _globals['_SKU']._serialized_start=96
  _globals['_SKU']._serialized_end=257
  _globals['_PRICINGVERSION']._serialized_start=260
  _globals['_PRICINGVERSION']._serialized_end=460
  _globals['_PRICINGEXPRESSION']._serialized_start=462
  _globals['_PRICINGEXPRESSION']._serialized_end=527
  _globals['_RATE']._serialized_start=529
  _globals['_RATE']._serialized_end=605
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.airflow.v1.cluster_pb2
import yandex.cloud.airflow.v1.maintenance_pb2
import yandex.cloud.operation.operation_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetClusterRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Apache Airflow Cluster resource to return."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___GetClusterRequest = GetClusterRequest

@typing.final
class ListClustersRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to list Apache Airflow clusters in."""
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size], the service returns a [ListClustersResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token] to the [ListClustersResponse.next_page_token]
    returned by the previous list request.
    """
    filter: builtins.str
    """A filter expression that filters resources listed in the response.
    The expression must specify:
    1. The field name. Currently you can only use filtering with the [Cluster.name] field.
    2. An `=` operator.
    3. The value in double quotes (`"`). Must be 1-63 characters long and match the regular expression `[a-zA-Z0-9_-]+`.
    """
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "folder_id", b"folder_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListClustersRequest = ListClustersRequest

@typing.final
class ListClustersResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTERS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListClustersRequest.page_size], use the [next_page_token] as the value
    for the [ListClustersRequest.page_token] parameter in the next list request. Each subsequent
    list request will have its own [next_page_token] to continue paging through the results.
    """
    @property
    def clusters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.airflow.v1.cluster_pb2.Cluster]:
        """List of Apache Airflow Cluster resources."""

    def __init__(
        self,
        *,
        clusters: collections.abc.Iterable[yandex.cloud.airflow.v1.cluster_pb2.Cluster] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["clusters", b"clusters", "next_page_token", b"next_page_token"]) -> None: ...

global___ListClustersResponse = ListClustersResponse

@typing.final
class CreateClusterRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    NETWORK_FIELD_NUMBER: builtins.int
    CODE_SYNC_FIELD_NUMBER: builtins.int
    DELETION_PROTECTION_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    LOGGING_FIELD_NUMBER: builtins.int
    ADMIN_PASSWORD_FIELD_NUMBER: builtins.int
    MAINTENANCE_WINDOW_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to create Apache Airflow cluster in."""
    name: builtins.str
    """Name of the Apache Airflow cluster. The name must be unique within the folder."""
    description: builtins.str
    """Description of the Apache Airflow cluster."""
    deletion_protection: builtins.bool
    """Deletion Protection inhibits deletion of the cluster."""
    service_account_id: builtins.str
    """Service account used to access Cloud resources.
    For more information, see [documentation](/docs/managed-airflow/concepts/impersonation).
    """
    admin_password: builtins.str
    """Password of user `admin`."""
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Custom labels for the Apache Airflow cluster as `` key:value `` pairs. For example, "env": "prod"."""

    @property
    def config(self) -> yandex.cloud.airflow.v1.cluster_pb2.ClusterConfig:
        """Configuration of Apache Airflow components."""

    @property
    def network(self) -> yandex.cloud.airflow.v1.cluster_pb2.NetworkConfig:
        """Network related configuration options."""

    @property
    def code_sync(self) -> yandex.cloud.airflow.v1.cluster_pb2.CodeSyncConfig:
        """Parameters of the location and access to the code that will be executed in the cluster."""

    @property
    def logging(self) -> yandex.cloud.airflow.v1.cluster_pb2.LoggingConfig:
        """Cloud Logging configuration."""

    @property
    def maintenance_window(self) -> yandex.cloud.airflow.v1.maintenance_pb2.MaintenanceWindow:
        """Window of maintenance operations."""

    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        config: yandex.cloud.airflow.v1.cluster_pb2.ClusterConfig | None = ...,
        network: yandex.cloud.airflow.v1.cluster_pb2.NetworkConfig | None = ...,
        code_sync: yandex.cloud.airflow.v1.cluster_pb2.CodeSyncConfig | None = ...,
        deletion_protection: builtins.bool = ...,
        service_account_id: builtins.str = ...,
        logging: yandex.cloud.airflow.v1.cluster_pb2.LoggingConfig | None = ...,
        admin_password: builtins.str = ...,
        maintenance_window: yandex.cloud.airflow.v1.maintenance_pb2.MaintenanceWindow | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["code_sync", b"code_sync", "config", b"config", "logging", b"logging", "maintenance_window", b"maintenance_window", "network", b"network"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["admin_password", b"admin_password", "code_sync", b"code_sync", "config", b"config", "deletion_protection", b"deletion_protection", "description", b"description", "folder_id", b"folder_id", "labels", b"labels", "logging", b"logging", "maintenance_window", b"maintenance_window", "name", b"name", "network", b"network", "service_account_id", b"service_account_id"]) -> None: ...

global___CreateClusterRequest = CreateClusterRequest

@typing.final
class CreateClusterMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Apache Airflow cluster that is being created."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___CreateClusterMetadata = CreateClusterMetadata

@typing.final
class UpdateClusterConfigSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AIRFLOW_FIELD_NUMBER: builtins.int
    WEBSERVER_FIELD_NUMBER: builtins.int
    SCHEDULER_FIELD_NUMBER: builtins.int
    TRIGGERER_FIELD_NUMBER: builtins.int
    WORKER_FIELD_NUMBER: builtins.int
    DEPENDENCIES_FIELD_NUMBER: builtins.int
    LOCKBOX_FIELD_NUMBER: builtins.int
    AIRFLOW_VERSION_FIELD_NUMBER: builtins.int
    PYTHON_VERSION_FIELD_NUMBER: builtins.int
    airflow_version: builtins.str
    """Apache Airflow version. Format: "Major.Minor" """
    python_version: builtins.str
    """Python version. Format: "Major.Minor" """
    @property
    def airflow(self) -> yandex.cloud.airflow.v1.cluster_pb2.AirflowConfig:
        """Configuration of the Apache Airflow application itself."""

    @property
    def webserver(self) -> yandex.cloud.airflow.v1.cluster_pb2.WebserverConfig:
        """Configuration of webserver instances."""

    @property
    def scheduler(self) -> yandex.cloud.airflow.v1.cluster_pb2.SchedulerConfig:
        """Configuration of scheduler instances."""

    @property
    def triggerer(self) -> yandex.cloud.airflow.v1.cluster_pb2.TriggererConfig:
        """Configuration of triggerer instances."""

    @property
    def worker(self) -> yandex.cloud.airflow.v1.cluster_pb2.WorkerConfig:
        """Configuration of worker instances."""

    @property
    def dependencies(self) -> yandex.cloud.airflow.v1.cluster_pb2.Dependencies:
        """The list of additional packages installed in the cluster."""

    @property
    def lockbox(self) -> yandex.cloud.airflow.v1.cluster_pb2.LockboxConfig:
        """Configuration of Lockbox Secret Backend."""

    def __init__(
        self,
        *,
        airflow: yandex.cloud.airflow.v1.cluster_pb2.AirflowConfig | None = ...,
        webserver: yandex.cloud.airflow.v1.cluster_pb2.WebserverConfig | None = ...,
        scheduler: yandex.cloud.airflow.v1.cluster_pb2.SchedulerConfig | None = ...,
        triggerer: yandex.cloud.airflow.v1.cluster_pb2.TriggererConfig | None = ...,
        worker: yandex.cloud.airflow.v1.cluster_pb2.WorkerConfig | None = ...,
        dependencies: yandex.cloud.airflow.v1.cluster_pb2.Dependencies | None = ...,
        lockbox: yandex.cloud.airflow.v1.cluster_pb2.LockboxConfig | None = ...,
        airflow_version: builtins.str = ...,
        python_version: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["airflow", b"airflow", "dependencies", b"dependencies", "lockbox", b"lockbox", "scheduler", b"scheduler", "triggerer", b"triggerer", "webserver", b"webserver", "worker", b"worker"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["airflow", b"airflow", "airflow_version", b"airflow_version", "dependencies", b"dependencies", "lockbox", b"lockbox", "python_version", b"python_version", "scheduler", b"scheduler", "triggerer", b"triggerer", "webserver", b"webserver", "worker", b"worker"]) -> None: ...

global___UpdateClusterConfigSpec = UpdateClusterConfigSpec

@typing.final
class UpdateNetworkConfigSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SECURITY_GROUP_IDS_FIELD_NUMBER: builtins.int
    @property
    def security_group_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """User security groups."""

    def __init__(
        self,
        *,
        security_group_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["security_group_ids", b"security_group_ids"]) -> None: ...

global___UpdateNetworkConfigSpec = UpdateNetworkConfigSpec

@typing.final
class UpdateClusterRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    CONFIG_SPEC_FIELD_NUMBER: builtins.int
    CODE_SYNC_FIELD_NUMBER: builtins.int
    NETWORK_SPEC_FIELD_NUMBER: builtins.int
    DELETION_PROTECTION_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    LOGGING_FIELD_NUMBER: builtins.int
    MAINTENANCE_WINDOW_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Apache Airflow Cluster resource to update."""
    name: builtins.str
    """New name of the cluster."""
    description: builtins.str
    """New description of the Apache Airflow cluster."""
    deletion_protection: builtins.bool
    """Deletion Protection inhibits deletion of the cluster"""
    service_account_id: builtins.str
    """Service account used to access Cloud resources.
    For more information, see [documentation](/docs/managed-airflow/concepts/impersonation).
    """
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which fields of the Apache Airflow Cluster resource should be updated."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Custom labels for the Apache Airflow cluster as `` key:value `` pairs. For example, "env": "prod".

        The new set of labels will completely replace the old ones. To add a label, request the current
        set with the [ClusterService.Get] method, then send an [ClusterService.Update] request with the new label added to the set.
        """

    @property
    def config_spec(self) -> global___UpdateClusterConfigSpec:
        """Configuration of Apache Airflow components."""

    @property
    def code_sync(self) -> yandex.cloud.airflow.v1.cluster_pb2.CodeSyncConfig:
        """Parameters of the location and access to the code that will be executed in the cluster."""

    @property
    def network_spec(self) -> global___UpdateNetworkConfigSpec:
        """Network related configuration options."""

    @property
    def logging(self) -> yandex.cloud.airflow.v1.cluster_pb2.LoggingConfig:
        """Cloud Logging configuration."""

    @property
    def maintenance_window(self) -> yandex.cloud.airflow.v1.maintenance_pb2.MaintenanceWindow:
        """Window of maintenance operations."""

    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        config_spec: global___UpdateClusterConfigSpec | None = ...,
        code_sync: yandex.cloud.airflow.v1.cluster_pb2.CodeSyncConfig | None = ...,
        network_spec: global___UpdateNetworkConfigSpec | None = ...,
        deletion_protection: builtins.bool = ...,
        service_account_id: builtins.str = ...,
        logging: yandex.cloud.airflow.v1.cluster_pb2.LoggingConfig | None = ...,
        maintenance_window: yandex.cloud.airflow.v1.maintenance_pb2.MaintenanceWindow | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["code_sync", b"code_sync", "config_spec", b"config_spec", "logging", b"logging", "maintenance_window", b"maintenance_window", "network_spec", b"network_spec", "update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "code_sync", b"code_sync", "config_spec", b"config_spec", "deletion_protection", b"deletion_protection", "description", b"description", "labels", b"labels", "logging", b"logging", "maintenance_window", b"maintenance_window", "name", b"name", "network_spec", b"network_spec", "service_account_id", b"service_account_id", "update_mask", b"update_mask"]) -> None: ...

global___UpdateClusterRequest = UpdateClusterRequest

@typing.final
class UpdateClusterMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Apache Airflow Cluster resource that is being updated."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___UpdateClusterMetadata = UpdateClusterMetadata

@typing.final
class DeleteClusterRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Apache Airflow cluster to delete."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___DeleteClusterRequest = DeleteClusterRequest

@typing.final
class DeleteClusterMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Apache Airflow cluster that is being deleted."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___DeleteClusterMetadata = DeleteClusterMetadata

@typing.final
class StartClusterRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Apache Airflow cluster to start."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___StartClusterRequest = StartClusterRequest

@typing.final
class StartClusterMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Apache Airflow cluster that is being started."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___StartClusterMetadata = StartClusterMetadata

@typing.final
class StopClusterRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Apache Airflow cluster to stop."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___StopClusterRequest = StopClusterRequest

@typing.final
class StopClusterMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Apache Airflow cluster that is being stopped."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___StopClusterMetadata = StopClusterMetadata

@typing.final
class ListClusterOperationsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Apache Airflow Cluster resource to list operations for."""
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size], the service returns a [ListClusterOperationsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    """
    page_token: builtins.str
    """Page token.  To get the next page of results, set [page_token] to the [ListClusterOperationsResponse.next_page_token]
    returned by the previous list request.
    """
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListClusterOperationsRequest = ListClusterOperationsRequest

@typing.final
class ListClusterOperationsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListClusterOperationsRequest.page_size], use the [next_page_token] as the value
    for the [ListClusterOperationsRequest.page_token] query parameter in the next list request.
    Each subsequent list request will have its own [next_page_token] to continue paging through the results.
    """
    @property
    def operations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.operation.operation_pb2.Operation]:
        """List of Operation resources for the specified Apache Airflow cluster."""

    def __init__(
        self,
        *,
        operations: collections.abc.Iterable[yandex.cloud.operation.operation_pb2.Operation] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "operations", b"operations"]) -> None: ...

global___ListClusterOperationsResponse = ListClusterOperationsResponse



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/apploadbalancer/v1/virtual_host_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/apploadbalancer/v1/virtual_host_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.apploadbalancer.v1 import rate_limit_pb2 as yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_rate__limit__pb2
from yandex.cloud.apploadbalancer.v1 import virtual_host_pb2 as yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_virtual__host__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:yandex/cloud/apploadbalancer/v1/virtual_host_service.proto\x12\x1fyandex.cloud.apploadbalancer.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a\x30yandex/cloud/apploadbalancer/v1/rate_limit.proto\x1a\x32yandex/cloud/apploadbalancer/v1/virtual_host.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"|\n\x15GetVirtualHostRequest\x12\x1c\n\x0ehttp_router_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x45\n\x11virtual_host_name\x18\x02 \x01(\tB*\xe8\xc7\x31\x01\xf2\xc7\x31\"([a-z]([-a-z0-9]{0,61}[a-z0-9])?)?\"u\n\x17ListVirtualHostsRequest\x12\x1c\n\x0ehttp_router_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"x\n\x18ListVirtualHostsResponse\x12\x43\n\rvirtual_hosts\x18\x01 \x03(\x0b\x32,.yandex.cloud.apploadbalancer.v1.VirtualHost\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xf0\x03\n\x18\x43reateVirtualHostRequest\x12\x1c\n\x0ehttp_router_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x34\n\x04name\x18\x02 \x01(\tB&\xf2\xc7\x31\"([a-z]([-a-z0-9]{0,61}[a-z0-9])?)?\x12\x11\n\tauthority\x18\x03 \x03(\t\x12\x36\n\x06routes\x18\x05 \x03(\x0b\x32&.yandex.cloud.apploadbalancer.v1.Route\x12S\n\x16modify_request_headers\x18\x06 \x03(\x0b\x32\x33.yandex.cloud.apploadbalancer.v1.HeaderModification\x12T\n\x17modify_response_headers\x18\x07 \x03(\x0b\x32\x33.yandex.cloud.apploadbalancer.v1.HeaderModification\x12\x44\n\rroute_options\x18\x08 \x01(\x0b\x32-.yandex.cloud.apploadbalancer.v1.RouteOptions\x12>\n\nrate_limit\x18\t \x01(\x0b\x32*.yandex.cloud.apploadbalancer.v1.RateLimitJ\x04\x08\x04\x10\x05\"T\n\x19\x43reateVirtualHostMetadata\x12\x1c\n\x0ehttp_router_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x19\n\x11virtual_host_name\x18\x02 \x01(\t\"\x8c\x04\n\x18UpdateVirtualHostRequest\x12\x1c\n\x0ehttp_router_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1f\n\x11virtual_host_name\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12/\n\x0bupdate_mask\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x11\n\tauthority\x18\x04 \x03(\t\x12\x36\n\x06routes\x18\x06 \x03(\x0b\x32&.yandex.cloud.apploadbalancer.v1.Route\x12S\n\x16modify_request_headers\x18\x07 \x03(\x0b\x32\x33.yandex.cloud.apploadbalancer.v1.HeaderModification\x12T\n\x17modify_response_headers\x18\x08 \x03(\x0b\x32\x33.yandex.cloud.apploadbalancer.v1.HeaderModification\x12\x44\n\rroute_options\x18\t \x01(\x0b\x32-.yandex.cloud.apploadbalancer.v1.RouteOptions\x12>\n\nrate_limit\x18\n \x01(\x0b\x32*.yandex.cloud.apploadbalancer.v1.RateLimitJ\x04\x08\x05\x10\x06\"N\n\x19UpdateVirtualHostMetadata\x12\x16\n\x0ehttp_router_id\x18\x01 \x01(\t\x12\x19\n\x11virtual_host_name\x18\x02 \x01(\t\"\x7f\n\x18\x44\x65leteVirtualHostRequest\x12\x1c\n\x0ehttp_router_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x45\n\x11virtual_host_name\x18\x02 \x01(\tB*\xe8\xc7\x31\x01\xf2\xc7\x31\"([a-z]([-a-z0-9]{0,61}[a-z0-9])?)?\"N\n\x19\x44\x65leteVirtualHostMetadata\x12\x16\n\x0ehttp_router_id\x18\x01 \x01(\t\x12\x19\n\x11virtual_host_name\x18\x02 \x01(\t\"m\n\x12RemoveRouteRequest\x12\x1c\n\x0ehttp_router_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1f\n\x11virtual_host_name\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x18\n\nroute_name\x18\x03 \x01(\tB\x04\xe8\xc7\x31\x01\"\\\n\x13RemoveRouteMetadata\x12\x16\n\x0ehttp_router_id\x18\x01 \x01(\t\x12\x19\n\x11virtual_host_name\x18\x02 \x01(\t\x12\x12\n\nroute_name\x18\x03 \x01(\t\"\xeb\x02\n\x12UpdateRouteRequest\x12\x1c\n\x0ehttp_router_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1f\n\x11virtual_host_name\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x18\n\nroute_name\x18\x03 \x01(\tB\x04\xe8\xc7\x31\x01\x12/\n\x0bupdate_mask\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12:\n\x04http\x18\x05 \x01(\x0b\x32*.yandex.cloud.apploadbalancer.v1.HttpRouteH\x00\x12:\n\x04grpc\x18\x06 \x01(\x0b\x32*.yandex.cloud.apploadbalancer.v1.GrpcRouteH\x00\x12\x44\n\rroute_options\x18\x07 \x01(\x0b\x32-.yandex.cloud.apploadbalancer.v1.RouteOptionsB\r\n\x05route\x12\x04\xc0\xc1\x31\x01\"\\\n\x13UpdateRouteMetadata\x12\x16\n\x0ehttp_router_id\x18\x01 \x01(\t\x12\x19\n\x11virtual_host_name\x18\x02 \x01(\t\x12\x12\n\nroute_name\x18\x03 \x01(\t2\xe2\x0c\n\x12VirtualHostService\x12\xc6\x01\n\x03Get\x12\x36.yandex.cloud.apploadbalancer.v1.GetVirtualHostRequest\x1a,.yandex.cloud.apploadbalancer.v1.VirtualHost\"Y\x82\xd3\xe4\x93\x02S\x12Q/apploadbalancer/v1/httpRouters/{http_router_id}/virtualHosts/{virtual_host_name}\x12\xc2\x01\n\x04List\x12\x38.yandex.cloud.apploadbalancer.v1.ListVirtualHostsRequest\x1a\x39.yandex.cloud.apploadbalancer.v1.ListVirtualHostsResponse\"E\x82\xd3\xe4\x93\x02?\x12=/apploadbalancer/v1/httpRouters/{http_router_id}/virtualHosts\x12\xdc\x01\n\x06\x43reate\x12\x39.yandex.cloud.apploadbalancer.v1.CreateVirtualHostRequest\x1a!.yandex.cloud.operation.Operation\"t\xb2\xd2*(\n\x19\x43reateVirtualHostMetadata\x12\x0bVirtualHost\x82\xd3\xe4\x93\x02\x42\"=/apploadbalancer/v1/httpRouters/{http_router_id}/virtualHosts:\x01*\x12\xf1\x01\n\x06Update\x12\x39.yandex.cloud.apploadbalancer.v1.UpdateVirtualHostRequest\x1a!.yandex.cloud.operation.Operation\"\x88\x01\xb2\xd2*(\n\x19UpdateVirtualHostMetadata\x12\x0bVirtualHost\x82\xd3\xe4\x93\x02V2Q/apploadbalancer/v1/httpRouters/{http_router_id}/virtualHosts/{virtual_host_name}:\x01*\x12\xf8\x01\n\x06\x44\x65lete\x12\x39.yandex.cloud.apploadbalancer.v1.DeleteVirtualHostRequest\x1a!.yandex.cloud.operation.Operation\"\x8f\x01\xb2\xd2*2\n\x19\x44\x65leteVirtualHostMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02S*Q/apploadbalancer/v1/httpRouters/{http_router_id}/virtualHosts/{virtual_host_name}\x12\xf6\x01\n\x0bRemoveRoute\x12\x33.yandex.cloud.apploadbalancer.v1.RemoveRouteRequest\x1a!.yandex.cloud.operation.Operation\"\x8e\x01\xb2\xd2*\"\n\x13RemoveRouteMetadata\x12\x0bVirtualHost\x82\xd3\xe4\x93\x02\x62\"]/apploadbalancer/v1/httpRouters/{http_router_id}/virtualHosts/{virtual_host_name}:removeRoute:\x01*\x12\xf6\x01\n\x0bUpdateRoute\x12\x33.yandex.cloud.apploadbalancer.v1.UpdateRouteRequest\x1a!.yandex.cloud.operation.Operation\"\x8e\x01\xb2\xd2*\"\n\x13UpdateRouteMetadata\x12\x0bVirtualHost\x82\xd3\xe4\x93\x02\x62\"]/apploadbalancer/v1/httpRouters/{http_router_id}/virtualHosts/{virtual_host_name}:updateRoute:\x01*Bz\n#yandex.cloud.api.apploadbalancer.v1ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/apploadbalancer/v1;apploadbalancerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.apploadbalancer.v1.virtual_host_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n#yandex.cloud.api.apploadbalancer.v1ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/apploadbalancer/v1;apploadbalancer'
  _globals['_GETVIRTUALHOSTREQUEST'].fields_by_name['http_router_id']._loaded_options = None
  _globals['_GETVIRTUALHOSTREQUEST'].fields_by_name['http_router_id']._serialized_options = b'\350\3071\001'
  _globals['_GETVIRTUALHOSTREQUEST'].fields_by_name['virtual_host_name']._loaded_options = None
  _globals['_GETVIRTUALHOSTREQUEST'].fields_by_name['virtual_host_name']._serialized_options = b'\350\3071\001\362\3071\"([a-z]([-a-z0-9]{0,61}[a-z0-9])?)?'
  _globals['_LISTVIRTUALHOSTSREQUEST'].fields_by_name['http_router_id']._loaded_options = None
  _globals['_LISTVIRTUALHOSTSREQUEST'].fields_by_name['http_router_id']._serialized_options = b'\350\3071\001'
  _globals['_LISTVIRTUALHOSTSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTVIRTUALHOSTSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTVIRTUALHOSTSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTVIRTUALHOSTSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_CREATEVIRTUALHOSTREQUEST'].fields_by_name['http_router_id']._loaded_options = None
  _globals['_CREATEVIRTUALHOSTREQUEST'].fields_by_name['http_router_id']._serialized_options = b'\350\3071\001'
  _globals['_CREATEVIRTUALHOSTREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_CREATEVIRTUALHOSTREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071\"([a-z]([-a-z0-9]{0,61}[a-z0-9])?)?'
  _globals['_CREATEVIRTUALHOSTMETADATA'].fields_by_name['http_router_id']._loaded_options = None
  _globals['_CREATEVIRTUALHOSTMETADATA'].fields_by_name['http_router_id']._serialized_options = b'\350\3071\001'
  _globals['_UPDATEVIRTUALHOSTREQUEST'].fields_by_name['http_router_id']._loaded_options = None
  _globals['_UPDATEVIRTUALHOSTREQUEST'].fields_by_name['http_router_id']._serialized_options = b'\350\3071\001'
  _globals['_UPDATEVIRTUALHOSTREQUEST'].fields_by_name['virtual_host_name']._loaded_options = None
  _globals['_UPDATEVIRTUALHOSTREQUEST'].fields_by_name['virtual_host_name']._serialized_options = b'\350\3071\001'
  _globals['_DELETEVIRTUALHOSTREQUEST'].fields_by_name['http_router_id']._loaded_options = None
  _globals['_DELETEVIRTUALHOSTREQUEST'].fields_by_name['http_router_id']._serialized_options = b'\350\3071\001'
  _globals['_DELETEVIRTUALHOSTREQUEST'].fields_by_name['virtual_host_name']._loaded_options = None
  _globals['_DELETEVIRTUALHOSTREQUEST'].fields_by_name['virtual_host_name']._serialized_options = b'\350\3071\001\362\3071\"([a-z]([-a-z0-9]{0,61}[a-z0-9])?)?'
  _globals['_REMOVEROUTEREQUEST'].fields_by_name['http_router_id']._loaded_options = None
  _globals['_REMOVEROUTEREQUEST'].fields_by_name['http_router_id']._serialized_options = b'\350\3071\001'
  _globals['_REMOVEROUTEREQUEST'].fields_by_name['virtual_host_name']._loaded_options = None
  _globals['_REMOVEROUTEREQUEST'].fields_by_name['virtual_host_name']._serialized_options = b'\350\3071\001'
  _globals['_REMOVEROUTEREQUEST'].fields_by_name['route_name']._loaded_options = None
  _globals['_REMOVEROUTEREQUEST'].fields_by_name['route_name']._serialized_options = b'\350\3071\001'
  _globals['_UPDATEROUTEREQUEST'].oneofs_by_name['route']._loaded_options = None
  _globals['_UPDATEROUTEREQUEST'].oneofs_by_name['route']._serialized_options = b'\300\3011\001'
  _globals['_UPDATEROUTEREQUEST'].fields_by_name['http_router_id']._loaded_options = None
  _globals['_UPDATEROUTEREQUEST'].fields_by_name['http_router_id']._serialized_options = b'\350\3071\001'
  _globals['_UPDATEROUTEREQUEST'].fields_by_name['virtual_host_name']._loaded_options = None
  _globals['_UPDATEROUTEREQUEST'].fields_by_name['virtual_host_name']._serialized_options = b'\350\3071\001'
  _globals['_UPDATEROUTEREQUEST'].fields_by_name['route_name']._loaded_options = None
  _globals['_UPDATEROUTEREQUEST'].fields_by_name['route_name']._serialized_options = b'\350\3071\001'
  _globals['_VIRTUALHOSTSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_VIRTUALHOSTSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002S\022Q/apploadbalancer/v1/httpRouters/{http_router_id}/virtualHosts/{virtual_host_name}'
  _globals['_VIRTUALHOSTSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_VIRTUALHOSTSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002?\022=/apploadbalancer/v1/httpRouters/{http_router_id}/virtualHosts'
  _globals['_VIRTUALHOSTSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_VIRTUALHOSTSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322*(\n\031CreateVirtualHostMetadata\022\013VirtualHost\202\323\344\223\002B\"=/apploadbalancer/v1/httpRouters/{http_router_id}/virtualHosts:\001*'
  _globals['_VIRTUALHOSTSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_VIRTUALHOSTSERVICE'].methods_by_name['Update']._serialized_options = b'\262\322*(\n\031UpdateVirtualHostMetadata\022\013VirtualHost\202\323\344\223\002V2Q/apploadbalancer/v1/httpRouters/{http_router_id}/virtualHosts/{virtual_host_name}:\001*'
  _globals['_VIRTUALHOSTSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_VIRTUALHOSTSERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*2\n\031DeleteVirtualHostMetadata\022\025google.protobuf.Empty\202\323\344\223\002S*Q/apploadbalancer/v1/httpRouters/{http_router_id}/virtualHosts/{virtual_host_name}'
  _globals['_VIRTUALHOSTSERVICE'].methods_by_name['RemoveRoute']._loaded_options = None
  _globals['_VIRTUALHOSTSERVICE'].methods_by_name['RemoveRoute']._serialized_options = b'\262\322*\"\n\023RemoveRouteMetadata\022\013VirtualHost\202\323\344\223\002b\"]/apploadbalancer/v1/httpRouters/{http_router_id}/virtualHosts/{virtual_host_name}:removeRoute:\001*'
  _globals['_VIRTUALHOSTSERVICE'].methods_by_name['UpdateRoute']._loaded_options = None
  _globals['_VIRTUALHOSTSERVICE'].methods_by_name['UpdateRoute']._serialized_options = b'\262\322*\"\n\023UpdateRouteMetadata\022\013VirtualHost\202\323\344\223\002b\"]/apploadbalancer/v1/httpRouters/{http_router_id}/virtualHosts/{virtual_host_name}:updateRoute:\001*'
  _globals['_GETVIRTUALHOSTREQUEST']._serialized_start=366
  _globals['_GETVIRTUALHOSTREQUEST']._serialized_end=490
  _globals['_LISTVIRTUALHOSTSREQUEST']._serialized_start=492
  _globals['_LISTVIRTUALHOSTSREQUEST']._serialized_end=609
  _globals['_LISTVIRTUALHOSTSRESPONSE']._serialized_start=611
  _globals['_LISTVIRTUALHOSTSRESPONSE']._serialized_end=731
  _globals['_CREATEVIRTUALHOSTREQUEST']._serialized_start=734
  _globals['_CREATEVIRTUALHOSTREQUEST']._serialized_end=1230
  _globals['_CREATEVIRTUALHOSTMETADATA']._serialized_start=1232
  _globals['_CREATEVIRTUALHOSTMETADATA']._serialized_end=1316
  _globals['_UPDATEVIRTUALHOSTREQUEST']._serialized_start=1319
  _globals['_UPDATEVIRTUALHOSTREQUEST']._serialized_end=1843
  _globals['_UPDATEVIRTUALHOSTMETADATA']._serialized_start=1845
  _globals['_UPDATEVIRTUALHOSTMETADATA']._serialized_end=1923
  _globals['_DELETEVIRTUALHOSTREQUEST']._serialized_start=1925
  _globals['_DELETEVIRTUALHOSTREQUEST']._serialized_end=2052
  _globals['_DELETEVIRTUALHOSTMETADATA']._serialized_start=2054
  _globals['_DELETEVIRTUALHOSTMETADATA']._serialized_end=2132
  _globals['_REMOVEROUTEREQUEST']._serialized_start=2134
  _globals['_REMOVEROUTEREQUEST']._serialized_end=2243
  _globals['_REMOVEROUTEMETADATA']._serialized_start=2245
  _globals['_REMOVEROUTEMETADATA']._serialized_end=2337
  _globals['_UPDATEROUTEREQUEST']._serialized_start=2340
  _globals['_UPDATEROUTEREQUEST']._serialized_end=2703
  _globals['_UPDATEROUTEMETADATA']._serialized_start=2705
  _globals['_UPDATEROUTEMETADATA']._serialized_end=2797
  _globals['_VIRTUALHOSTSERVICE']._serialized_start=2800
  _globals['_VIRTUALHOSTSERVICE']._serialized_end=4434
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Timeline(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PERIOD_FIELD_NUMBER: builtins.int
    REFRESH_INTERVAL_FIELD_NUMBER: builtins.int
    period: builtins.str
    """default time window"""
    refresh_interval: builtins.int
    """default refresh interval"""
    def __init__(
        self,
        *,
        period: builtins.str = ...,
        refresh_interval: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["period", b"period", "refresh_interval", b"refresh_interval"]) -> None: ...

global___Timeline = Timeline



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/mdb/greenplum/v1/resource_groups_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/mdb/greenplum/v1/resource_groups_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.mdb.greenplum.v1 import resource_groups_pb2 as yandex_dot_cloud_dot_mdb_dot_greenplum_dot_v1_dot_resource__groups__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;yandex/cloud/mdb/greenplum/v1/resource_groups_service.proto\x12\x1dyandex.cloud.mdb.greenplum.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x33yandex/cloud/mdb/greenplum/v1/resource_groups.proto\"\x81\x01\n\x1b\x43reateResourceGroupMetadata\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12@\n\x13resource_group_name\x18\x02 \x01(\tB#\xe8\xc7\x31\x01\xf2\xc7\x31\x12^[^\\|/*?.,;\"\'<>]+$\x8a\xc8\x31\x05\x33-200\"\x81\x01\n\x1bUpdateResourceGroupMetadata\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12@\n\x13resource_group_name\x18\x02 \x01(\tB#\xe8\xc7\x31\x01\xf2\xc7\x31\x12^[^\\|/*?.,;\"\'<>]+$\x8a\xc8\x31\x05\x33-200\"\x81\x01\n\x1b\x44\x65leteResourceGroupMetadata\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12@\n\x13resource_group_name\x18\x02 \x01(\tB#\xe8\xc7\x31\x01\xf2\xc7\x31\x12^[^\\|/*?.,;\"\'<>]+$\x8a\xc8\x31\x05\x33-200\"=\n\x19ListResourceGroupsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"c\n\x1aListResourceGroupsResponse\x12\x45\n\x0fresource_groups\x18\x01 \x03(\x0b\x32,.yandex.cloud.mdb.greenplum.v1.ResourceGroup\"\xa1\x01\n!GetResourceGroupAtRevisionRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x18\n\x08revision\x18\x02 \x01(\x03\x42\x06\xfa\xc7\x31\x02>0\x12@\n\x13resource_group_name\x18\x03 \x01(\tB#\xe8\xc7\x31\x01\xf2\xc7\x31\x12^[^\\|/*?.,;\"\'<>]+$\x8a\xc8\x31\x05\x33-200\"\x84\x01\n\x1a\x43reateResourceGroupRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x44\n\x0eresource_group\x18\x02 \x01(\x0b\x32,.yandex.cloud.mdb.greenplum.v1.ResourceGroup\"\xb5\x01\n\x1aUpdateResourceGroupRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x44\n\x0eresource_group\x18\x03 \x01(\x0b\x32,.yandex.cloud.mdb.greenplum.v1.ResourceGroup\"\x80\x01\n\x1a\x44\x65leteResourceGroupRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12@\n\x13resource_group_name\x18\x02 \x01(\tB#\xe8\xc7\x31\x01\xf2\xc7\x31\x12^[^\\|/*?.,;\"\'<>]+$\x8a\xc8\x31\x05\x33-2002\xe6\x08\n\x14ResourceGroupService\x12\xc0\x01\n\x04List\x12\x38.yandex.cloud.mdb.greenplum.v1.ListResourceGroupsRequest\x1a\x39.yandex.cloud.mdb.greenplum.v1.ListResourceGroupsResponse\"C\x82\xd3\xe4\x93\x02=\x12;/managed-greenplum/v1/clusters/{cluster_id}/resource_groups\x12\xcb\x01\n\rGetAtRevision\x12@.yandex.cloud.mdb.greenplum.v1.GetResourceGroupAtRevisionRequest\x1a,.yandex.cloud.mdb.greenplum.v1.ResourceGroup\"J\x82\xd3\xe4\x93\x02\x44\x12\x42/managed-greenplum/v1/clusters/{cluster_id}/resource_groups/at_rev\x12\xde\x01\n\x06\x43reate\x12\x39.yandex.cloud.mdb.greenplum.v1.CreateResourceGroupRequest\x1a!.yandex.cloud.operation.Operation\"v\xb2\xd2*,\n\x1b\x43reateResourceGroupMetadata\x12\rResourceGroup\x82\xd3\xe4\x93\x02@\";/managed-greenplum/v1/clusters/{cluster_id}/resource_groups:\x01*\x12\xde\x01\n\x06Update\x12\x39.yandex.cloud.mdb.greenplum.v1.UpdateResourceGroupRequest\x1a!.yandex.cloud.operation.Operation\"v\xb2\xd2*,\n\x1bUpdateResourceGroupMetadata\x12\rResourceGroup\x82\xd3\xe4\x93\x02@2;/managed-greenplum/v1/clusters/{cluster_id}/resource_groups:\x01*\x12\xfa\x01\n\x06\x44\x65lete\x12\x39.yandex.cloud.mdb.greenplum.v1.DeleteResourceGroupRequest\x1a!.yandex.cloud.operation.Operation\"\x91\x01\xb2\xd2*4\n\x1b\x44\x65leteResourceGroupMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02S*Q/managed-greenplum/v1/clusters/{cluster_id}/resource_groups/{resource_group_name}Bp\n!yandex.cloud.api.mdb.greenplum.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/greenplum/v1;greenplumb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.greenplum.v1.resource_groups_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n!yandex.cloud.api.mdb.greenplum.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/greenplum/v1;greenplum'
  _globals['_CREATERESOURCEGROUPMETADATA'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_CREATERESOURCEGROUPMETADATA'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATERESOURCEGROUPMETADATA'].fields_by_name['resource_group_name']._loaded_options = None
  _globals['_CREATERESOURCEGROUPMETADATA'].fields_by_name['resource_group_name']._serialized_options = b'\350\3071\001\362\3071\022^[^\\|/*?.,;\"\'<>]+$\212\3101\0053-200'
  _globals['_UPDATERESOURCEGROUPMETADATA'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_UPDATERESOURCEGROUPMETADATA'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATERESOURCEGROUPMETADATA'].fields_by_name['resource_group_name']._loaded_options = None
  _globals['_UPDATERESOURCEGROUPMETADATA'].fields_by_name['resource_group_name']._serialized_options = b'\350\3071\001\362\3071\022^[^\\|/*?.,;\"\'<>]+$\212\3101\0053-200'
  _globals['_DELETERESOURCEGROUPMETADATA'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_DELETERESOURCEGROUPMETADATA'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DELETERESOURCEGROUPMETADATA'].fields_by_name['resource_group_name']._loaded_options = None
  _globals['_DELETERESOURCEGROUPMETADATA'].fields_by_name['resource_group_name']._serialized_options = b'\350\3071\001\362\3071\022^[^\\|/*?.,;\"\'<>]+$\212\3101\0053-200'
  _globals['_LISTRESOURCEGROUPSREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_LISTRESOURCEGROUPSREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_GETRESOURCEGROUPATREVISIONREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_GETRESOURCEGROUPATREVISIONREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_GETRESOURCEGROUPATREVISIONREQUEST'].fields_by_name['revision']._loaded_options = None
  _globals['_GETRESOURCEGROUPATREVISIONREQUEST'].fields_by_name['revision']._serialized_options = b'\372\3071\002>0'
  _globals['_GETRESOURCEGROUPATREVISIONREQUEST'].fields_by_name['resource_group_name']._loaded_options = None
  _globals['_GETRESOURCEGROUPATREVISIONREQUEST'].fields_by_name['resource_group_name']._serialized_options = b'\350\3071\001\362\3071\022^[^\\|/*?.,;\"\'<>]+$\212\3101\0053-200'
  _globals['_CREATERESOURCEGROUPREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_CREATERESOURCEGROUPREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATERESOURCEGROUPREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_UPDATERESOURCEGROUPREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DELETERESOURCEGROUPREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_DELETERESOURCEGROUPREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DELETERESOURCEGROUPREQUEST'].fields_by_name['resource_group_name']._loaded_options = None
  _globals['_DELETERESOURCEGROUPREQUEST'].fields_by_name['resource_group_name']._serialized_options = b'\350\3071\001\362\3071\022^[^\\|/*?.,;\"\'<>]+$\212\3101\0053-200'
  _globals['_RESOURCEGROUPSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_RESOURCEGROUPSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002=\022;/managed-greenplum/v1/clusters/{cluster_id}/resource_groups'
  _globals['_RESOURCEGROUPSERVICE'].methods_by_name['GetAtRevision']._loaded_options = None
  _globals['_RESOURCEGROUPSERVICE'].methods_by_name['GetAtRevision']._serialized_options = b'\202\323\344\223\002D\022B/managed-greenplum/v1/clusters/{cluster_id}/resource_groups/at_rev'
  _globals['_RESOURCEGROUPSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_RESOURCEGROUPSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322*,\n\033CreateResourceGroupMetadata\022\rResourceGroup\202\323\344\223\002@\";/managed-greenplum/v1/clusters/{cluster_id}/resource_groups:\001*'
  _globals['_RESOURCEGROUPSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_RESOURCEGROUPSERVICE'].methods_by_name['Update']._serialized_options = b'\262\322*,\n\033UpdateResourceGroupMetadata\022\rResourceGroup\202\323\344\223\002@2;/managed-greenplum/v1/clusters/{cluster_id}/resource_groups:\001*'
  _globals['_RESOURCEGROUPSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_RESOURCEGROUPSERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*4\n\033DeleteResourceGroupMetadata\022\025google.protobuf.Empty\202\323\344\223\002S*Q/managed-greenplum/v1/clusters/{cluster_id}/resource_groups/{resource_group_name}'
  _globals['_CREATERESOURCEGROUPMETADATA']._serialized_start=317
  _globals['_CREATERESOURCEGROUPMETADATA']._serialized_end=446
  _globals['_UPDATERESOURCEGROUPMETADATA']._serialized_start=449
  _globals['_UPDATERESOURCEGROUPMETADATA']._serialized_end=578
  _globals['_DELETERESOURCEGROUPMETADATA']._serialized_start=581
  _globals['_DELETERESOURCEGROUPMETADATA']._serialized_end=710
  _globals['_LISTRESOURCEGROUPSREQUEST']._serialized_start=712
  _globals['_LISTRESOURCEGROUPSREQUEST']._serialized_end=773
  _globals['_LISTRESOURCEGROUPSRESPONSE']._serialized_start=775
  _globals['_LISTRESOURCEGROUPSRESPONSE']._serialized_end=874
  _globals['_GETRESOURCEGROUPATREVISIONREQUEST']._serialized_start=877
  _globals['_GETRESOURCEGROUPATREVISIONREQUEST']._serialized_end=1038
  _globals['_CREATERESOURCEGROUPREQUEST']._serialized_start=1041
  _globals['_CREATERESOURCEGROUPREQUEST']._serialized_end=1173
  _globals['_UPDATERESOURCEGROUPREQUEST']._serialized_start=1176
  _globals['_UPDATERESOURCEGROUPREQUEST']._serialized_end=1357
  _globals['_DELETERESOURCEGROUPREQUEST']._serialized_start=1360
  _globals['_DELETERESOURCEGROUPREQUEST']._serialized_end=1488
  _globals['_RESOURCEGROUPSERVICE']._serialized_start=1491
  _globals['_RESOURCEGROUPSERVICE']._serialized_end=2617
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/mdb/greenplum/v1/hba_rule.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/mdb/greenplum/v1/hba_rule.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,yandex/cloud/mdb/greenplum/v1/hba_rule.proto\x12\x1dyandex.cloud.mdb.greenplum.v1\x1a\x1dyandex/cloud/validation.proto\"\xa5\x03\n\x07HBARule\x12\x1c\n\x08priority\x18\x01 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12N\n\x0f\x63onnection_type\x18\x02 \x01(\x0e\x32\x35.yandex.cloud.mdb.greenplum.v1.HBARule.ConnectionType\x12\x16\n\x08\x64\x61tabase\x18\x03 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x12\n\x04user\x18\x04 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x15\n\x07\x61\x64\x64ress\x18\x05 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x46\n\x0b\x61uth_method\x18\x06 \x01(\x0e\x32\x31.yandex.cloud.mdb.greenplum.v1.HBARule.AuthMethod\"W\n\x0e\x43onnectionType\x12\x1f\n\x1b\x43ONNECTION_TYPE_UNSPECIFIED\x10\x00\x12\x08\n\x04HOST\x10\x01\x12\x0b\n\x07HOSTSSL\x10\x02\x12\r\n\tHOSTNOSSL\x10\x03\"H\n\nAuthMethod\x12\x1b\n\x17\x41UTH_METHOD_UNSPECIFIED\x10\x00\x12\x07\n\x03MD5\x10\x01\x12\x08\n\x04LDAP\x10\x02\x12\n\n\x06REJECT\x10\x03\x42p\n!yandex.cloud.api.mdb.greenplum.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/greenplum/v1;greenplumb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.greenplum.v1.hba_rule_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n!yandex.cloud.api.mdb.greenplum.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/greenplum/v1;greenplum'
  _globals['_HBARULE'].fields_by_name['priority']._loaded_options = None
  _globals['_HBARULE'].fields_by_name['priority']._serialized_options = b'\372\3071\0060-1000'
  _globals['_HBARULE'].fields_by_name['database']._loaded_options = None
  _globals['_HBARULE'].fields_by_name['database']._serialized_options = b'\350\3071\001'
  _globals['_HBARULE'].fields_by_name['user']._loaded_options = None
  _globals['_HBARULE'].fields_by_name['user']._serialized_options = b'\350\3071\001'
  _globals['_HBARULE'].fields_by_name['address']._loaded_options = None
  _globals['_HBARULE'].fields_by_name['address']._serialized_options = b'\350\3071\001'
  _globals['_HBARULE']._serialized_start=111
  _globals['_HBARULE']._serialized_end=532
  _globals['_HBARULE_CONNECTIONTYPE']._serialized_start=371
  _globals['_HBARULE_CONNECTIONTYPE']._serialized_end=458
  _globals['_HBARULE_AUTHMETHOD']._serialized_start=460
  _globals['_HBARULE_AUTHMETHOD']._serialized_end=532
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/serverless/eventrouter/v1/event_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/serverless/eventrouter/v1/event_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:yandex/cloud/serverless/eventrouter/v1/event_service.proto\x12&yandex.cloud.serverless.eventrouter.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1dyandex/cloud/validation.proto\"G\n\x0fPutEventRequest\x12\x14\n\x06\x62us_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1e\n\x04\x62ody\x18\x02 \x01(\tB\x10\xe8\xc7\x31\x01\x8a\xc8\x31\x08<=262144\"W\n\x11SendEventsRequest\x12\x1a\n\x0c\x63onnector_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12&\n\x07message\x18\x02 \x03(\tB\x15\x82\xc8\x31\x05\x31-100\x8a\xc8\x31\x08<=2621442\xaa\x02\n\x0c\x45ventService\x12\x86\x01\n\x03Put\x12\x37.yandex.cloud.serverless.eventrouter.v1.PutEventRequest\x1a\x16.google.protobuf.Empty\".\x82\xd3\xe4\x93\x02(\"#/eventrouter/v1/events/{bus_id}:put:\x01*\x12\x90\x01\n\x04Send\x12\x39.yandex.cloud.serverless.eventrouter.v1.SendEventsRequest\x1a\x16.google.protobuf.Empty\"5\x82\xd3\xe4\x93\x02/\"*/eventrouter/v1/events/{connector_id}:send:\x01*B\x8b\x01\n*yandex.cloud.api.serverless.eventrouter.v1B\x05PERESZVgithub.com/yandex-cloud/go-genproto/yandex/cloud/serverless/eventrouter/v1;eventrouterb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.serverless.eventrouter.v1.event_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n*yandex.cloud.api.serverless.eventrouter.v1B\005PERESZVgithub.com/yandex-cloud/go-genproto/yandex/cloud/serverless/eventrouter/v1;eventrouter'
  _globals['_PUTEVENTREQUEST'].fields_by_name['bus_id']._loaded_options = None
  _globals['_PUTEVENTREQUEST'].fields_by_name['bus_id']._serialized_options = b'\350\3071\001'
  _globals['_PUTEVENTREQUEST'].fields_by_name['body']._loaded_options = None
  _globals['_PUTEVENTREQUEST'].fields_by_name['body']._serialized_options = b'\350\3071\001\212\3101\010<=262144'
  _globals['_SENDEVENTSREQUEST'].fields_by_name['connector_id']._loaded_options = None
  _globals['_SENDEVENTSREQUEST'].fields_by_name['connector_id']._serialized_options = b'\350\3071\001'
  _globals['_SENDEVENTSREQUEST'].fields_by_name['message']._loaded_options = None
  _globals['_SENDEVENTSREQUEST'].fields_by_name['message']._serialized_options = b'\202\3101\0051-100\212\3101\010<=262144'
  _globals['_EVENTSERVICE'].methods_by_name['Put']._loaded_options = None
  _globals['_EVENTSERVICE'].methods_by_name['Put']._serialized_options = b'\202\323\344\223\002(\"#/eventrouter/v1/events/{bus_id}:put:\001*'
  _globals['_EVENTSERVICE'].methods_by_name['Send']._loaded_options = None
  _globals['_EVENTSERVICE'].methods_by_name['Send']._serialized_options = b'\202\323\344\223\002/\"*/eventrouter/v1/events/{connector_id}:send:\001*'
  _globals['_PUTEVENTREQUEST']._serialized_start=192
  _globals['_PUTEVENTREQUEST']._serialized_end=263
  _globals['_SENDEVENTSREQUEST']._serialized_start=265
  _globals['_SENDEVENTSREQUEST']._serialized_end=352
  _globals['_EVENTSERVICE']._serialized_start=355
  _globals['_EVENTSERVICE']._serialized_end=653
# @@protoc_insertion_point(module_scope)
